@@ -3,7 +3,7 @@
 import django_tables2 as tables
 from django.utils.html import format_html
 from django.urls import reverse
-from schema.funcs import boolicon, colouricon, locationicon
+from schema.funcs import boolicon, colouricon
 
 # Import all models that need admin pages
 from schema.models import Accessory, Archive, Battery, BulkFilm, Camera, CameraModel, Developer, Enlarger, EnlargerModel, FilmStock, Filter
@@ -125,7 +125,7 @@ class CameraModelTable(tables.Table):
     class Meta:
         attrs = {"class": "table table-hover"}
         model = CameraModel
-        fields = ('model', 'image', 'mount', 'format',
+        fields = ('model', 'mount', 'lens_model_name', 'format',
                   'introduced', 'body_type', 'negative_size')
 
     @classmethod
@@ -138,7 +138,7 @@ class CameraModelTable(tables.Table):
                 'schema:cameramodel-detail', args=[record.slug]), record.manufacturer, value)
         if cls.request.user.is_authenticated:
             qty = Camera.objects.filter(
-                owner=cls.request.user, cameramodel=record).count()
+                owner=cls.request.user, own=True, cameramodel=record).count()
             if qty > 0:
                 badge = format_html(
                     " <span class=\"badge badge-pill badge-primary\">{}</span>", qty)
@@ -148,13 +148,6 @@ class CameraModelTable(tables.Table):
             badge = format_html("")
         return mystr+badge
 
-    @classmethod
-    def render_image(cls, value):
-        if value:
-            icon = format_html(
-                '<img src="/static/svg/camera.svg" width="20" height="20" alt="This camera model has a photo" title="This camera model has a photo">')
-        return icon
-
     @classmethod
     def render_mount(cls, value):
         return format_html("<a href=\"{}\">{}</a>", reverse('schema:mount-detail', args=[value.slug]), value)
@@ -319,7 +312,7 @@ class LensModelTable(tables.Table):
     class Meta:
         attrs = {"class": "table table-hover"}
         model = LensModel
-        fields = ('model', 'image', 'mount', 'zoom', 'min_focal_length',
+        fields = ('model', 'mount', 'zoom', 'min_focal_length',
                   'max_aperture', 'autofocus', 'introduced')
 
     @classmethod
@@ -332,7 +325,7 @@ class LensModelTable(tables.Table):
                 'schema:lensmodel-detail', args=[record.slug]), record.manufacturer, value)
         if cls.request.user.is_authenticated:
             qty = Lens.objects.filter(
-                owner=cls.request.user, lensmodel=record).count()
+                owner=cls.request.user, own=True, lensmodel=record).count()
             if qty > 0:
                 badge = format_html(
                     " <span class=\"badge badge-pill badge-primary\">{}</span>", qty)
@@ -342,13 +335,6 @@ class LensModelTable(tables.Table):
             badge = format_html("")
         return mystr+badge
 
-    @classmethod
-    def render_image(cls, value):
-        if value:
-            icon = format_html(
-                '<img src="/static/svg/camera.svg" width="20" height="20" alt="This lens model has a photo" title="This lens model has a photo">')
-        return icon
-
     @classmethod
     def render_mount(cls, value):
         return format_html("<a href=\"{}\">{}</a>", reverse('schema:mount-detail', args=[value.slug]), value)
@@ -426,6 +412,13 @@ class MountAdapterTable(tables.Table):
     def render_lens_mount(cls, value):
         return format_html("<a href=\"{}\">{}</a>", reverse('schema:mount-detail', args=[value.slug]), value)
 
+    @classmethod
+    def render_has_optics(cls, value):
+        return format_html(boolicon(value))
+
+    @classmethod
+    def render_infinity_focus(cls, value):
+        return format_html(boolicon(value))
 
 class NegativeSizeTable(tables.Table):
     class Meta:
@@ -584,7 +577,7 @@ class NegativeTable(tables.Table):
     class Meta:
         attrs = {"class": "table table-hover"}
         model = Negative
-        fields = ('slug', 'film', 'date', 'location', 'film__camera', 'lens', 'shutter_speed', 'aperture')
+        fields = ('slug', 'film', 'date', 'film__camera', 'lens', 'shutter_speed', 'aperture')
 
     @classmethod
     def render_slug(cls, value, record):
@@ -598,10 +591,6 @@ class NegativeTable(tables.Table):
     def render_film(cls, value):
         return format_html("<a href=\"{}\">{}</a>", reverse('schema:film-detail', args=[value.id_owner]), value)
 
-    @classmethod
-    def render_location(cls, value):
-        return format_html(locationicon(value))
-
     @classmethod
     def render_film__camera(cls, value):
         return format_html("<a href=\"{}\">{}</a>", reverse('schema:camera-detail', args=[value.id_owner]), value)
